wepy.resampling package
=======================

.. automodule:: wepy.resampling
   :members:
   :undoc-members:
   :show-inheritance:

Subpackages
-----------

.. toctree::

   wepy.resampling.decisions
   wepy.resampling.distances
   wepy.resampling.resamplers
